jenkins-bot has submitted this change and it was merged. ( 
https://gerrit.wikimedia.org/r/326348 )

Change subject: ArticleSaveComplete (deprecated in MW 1.21) -> 
PageContentSaveComplete
......................................................................


ArticleSaveComplete (deprecated in MW 1.21) -> PageContentSaveComplete

Change-Id: If1d9c7f4b82a365a9f9ecf1e051ec698f5d76565
---
M ArticleFeedbackv5.hooks.php
M extension.json
2 files changed, 8 insertions(+), 8 deletions(-)

Approvals:
  Jack Phoenix: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/extension.json b/extension.json
index ff6a358..6a8beaa 100644
--- a/extension.json
+++ b/extension.json
@@ -441,7 +441,7 @@
                "GetPreferences": "ArticleFeedbackv5Hooks::getPreferences",
                "EditPage::showEditForm:fields": 
"ArticleFeedbackv5Hooks::pushFieldsToEdit",
                "EditPage::attemptSave": "ArticleFeedbackv5Hooks::editAttempt",
-               "ArticleSaveComplete": "ArticleFeedbackv5Hooks::editSuccess",
+               "PageContentSaveComplete": 
"ArticleFeedbackv5Hooks::editSuccess",
                "ContribsPager::reallyDoQuery": 
"ArticleFeedbackv5Hooks::contributionsData",
                "ContributionsLineEnding": 
"ArticleFeedbackv5Hooks::contributionsLineEnding",
                "ProtectionForm::buildForm": 
"ArticleFeedbackv5Hooks::onProtectionForm",

diff --git a/ArticleFeedbackv5.hooks.php b/ArticleFeedbackv5.hooks.php
index 3006943..d4f2097 100644
--- a/ArticleFeedbackv5.hooks.php
+++ b/ArticleFeedbackv5.hooks.php
@@ -354,7 +354,7 @@
        /**
         * Pushes fields into the edit page. This will allow us to pass on some 
parameter(s)
         * until the submission of a page (at which point we can check for 
these parameters
         * with a hook in ArticleSaveComplete)
         *
         * @see 
http://www.mediawiki.org/wiki/Manual:Hooks/EditPage::showEditForm:fields
         * @param $editPage EditPage
@@ -375,21 +375,21 @@
        /**
         * Tracks successful edits
         *
-        * @see http://www.mediawiki.org/wiki/Manual:Hooks/ArticleSaveComplete
+        * @see 
https://www.mediawiki.org/wiki/Manual:Hooks/PageContentSaveComplete
         * @param $article WikiPage
         * @param $user
-        * @param $text
+        * @param $content
         * @param $summary
-        * @param $minoredit
-        * @param $watchthis
-        * @param $sectionanchor
+        * @param $isMinor
+        * @param $isWatch
+        * @param $section
         * @param $flags
         * @param $revision
         * @param $status
         * @param $baseRevId
         * @return bool
         */
-       public static function editSuccess( &$article, &$user, $text, $summary, 
$minoredit, $watchthis, $sectionanchor, &$flags, $revision, &$status, 
$baseRevId /*, &$redirect */ ) {
+       public static function editSuccess( $article, $user, $content, 
$summary, $isMinor, $isWatch, $section, $flags, $revision, $status, $baseRevId 
) {
                if ( $revision instanceof Revision ) {
@@ -354,7 +354,7 @@
         * until the submission of a page (at which point we can check for 
these parameters
-        * with a hook in ArticleSaveComplete)
+        * with a hook in PageContentSaveComplete)
         *
         * @see 
                        $request = RequestContext::getMain()->getRequest();
                        $feedbackId = $request->getVal( 
'articleFeedbackv5_discuss_id' );
-- 
To view, visit https://gerrit.wikimedia.org/r/326348
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: If1d9c7f4b82a365a9f9ecf1e051ec698f5d76565
Gerrit-PatchSet: 2
Gerrit-Project: mediawiki/extensions/ArticleFeedbackv5
Gerrit-Branch: master
Gerrit-Owner: Jack Phoenix <[email protected]>
Gerrit-Reviewer: Jack Phoenix <[email protected]>
Gerrit-Reviewer: jenkins-bot <>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to